<?php
/**
 * Czech language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Bohumir Zamecnik <bohumir@zamecnik.org>
 * @author Tomas Valenta <t.valenta@sh.cvut.cz>
 * @author Tomas Valenta <tomas@valenta.cz>
 * @author Zbynek Krivka <zbynek.krivka@seznam.cz>
 * @author Marek Sacha <sachamar@fel.cvut.cz>
 * @author Lefty <lefty@multihost.cz>
 * @author Vojta Beran <xmamut@email.cz>
 * @author zbynek.krivka@seznam.cz
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '\'';
$lang['btn_edit']              = 'Upravit stránku';
$lang['btn_source']            = 'Zdrojový kód stránky';
$lang['btn_show']              = 'Zobrazit stránku';
$lang['btn_create']            = 'Vytvořit stránku';
$lang['btn_search']            = 'Hledat';
$lang['btn_save']              = 'Uložit';
$lang['btn_preview']           = 'Náhled';
$lang['btn_top']               = 'Nahoru';
$lang['btn_newer']             = '<< novější';
$lang['btn_older']             = 'starší >>';
$lang['btn_revs']              = 'Starší verze';
$lang['btn_recent']            = 'Poslední úpravy';
$lang['btn_upload']            = 'Načíst';
$lang['btn_cancel']            = 'Storno';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Upravit';
$lang['btn_login']             = 'Přihlásit se';
$lang['btn_logout']            = 'Odhlásit se';
$lang['btn_admin']             = 'Správa';
$lang['btn_update']            = 'Aktualizovat';
$lang['btn_delete']            = 'Vymazat';
$lang['btn_back']              = 'Zpět';
$lang['btn_backlink']          = 'Zpětné odkazy';
$lang['btn_backtomedia']       = 'Zpět do Výběru dokumentu';
$lang['btn_subscribe']         = 'Odebírat emailem změny stránky';
$lang['btn_profile']           = 'Upravit profil';
$lang['btn_reset']             = 'Reset';
$lang['btn_resendpwd']         = 'Zaslat nové heslo';
$lang['btn_draft']             = 'Upravit koncept';
$lang['btn_recover']           = 'Obnovit koncept';
$lang['btn_draftdel']          = 'Vymazat koncept';
$lang['btn_revert']            = 'Vrátit zpět';
$lang['btn_register']          = 'Registrovat';
$lang['btn_apply']             = 'Použít';
$lang['btn_media']             = 'Správa médií';
$lang['loggedinas']            = 'Přihlášen(a) jako';
$lang['user']                  = 'Uživatelské jméno';
$lang['pass']                  = 'Heslo';
$lang['newpass']               = 'Nové heslo';
$lang['oldpass']               = 'Současné heslo';
$lang['passchk']               = 'ještě jednou';
$lang['remember']              = 'Přihlásit se nastálo';
$lang['fullname']              = 'Celé jméno';
$lang['email']                 = 'E-mail';
$lang['profile']               = 'Uživatelský profil';
$lang['badlogin']              = 'Zadané uživatelské jméno a heslo není správně.';
$lang['minoredit']             = 'Drobné změny';
$lang['draftdate']             = 'Koncept automaticky uložen v';
$lang['nosecedit']             = 'Stránka byla v mezičase změněna. Informace o sekci již nebylo platné, byla načtena celá stránka.';
$lang['regmissing']            = 'Musíte vyplnit všechny údaje.';
$lang['reguexists']            = 'Uživatel se stejným jménem už je zaregistrován.';
$lang['regsuccess']            = 'Uživatelský účet byl vytvořen a heslo zasláno mailem.';
$lang['regsuccess2']           = 'Uživatelský účet byl vytvořen.';
$lang['regmailfail']           = 'Zdá se, že nastala chyba při posílání mailu s heslem. Zkuste kontaktovat správce.';
$lang['regbadmail']            = 'Zadaná mailová adresa není platná. Pokud si myslíte, že to je špatně, zkuste kontaktovat správce.';
$lang['regbadpass']            = 'Heslo nebylo zadáno dvakrát stejně, zkuste to prosím znovu.';
$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
$lang['reghere']               = 'Nemáte uživatelský účet? Zřiďte si ho';
$lang['profna']                = 'Tato wiki neumožňuje změnu profilu';
$lang['profnochange']          = 'Žádné změny nebyly provedeny.';
$lang['profnoempty']           = 'Nelze zadat prázdné jméno nebo mailová adresa.';
$lang['profchanged']           = 'Uživatelský profil změněn.';
$lang['pwdforget']             = 'Zapomněli jste heslo? Nechte si zaslat nové';
$lang['resendna']              = 'Tato wiki neumožňuje zasílání nových hesel.';
$lang['resendpwd']             = 'Odeslat nové heslo pro uživatele';
$lang['resendpwdmissing']      = 'Musíte vyplnit všechny položky.';
$lang['resendpwdnouser']       = 'Bohužel takový uživatel v systému není.';
$lang['resendpwdbadauth']      = 'Autorizační kód není platný. Zadali jste opravdu celý odkaz na potvrzovací stránku?';
$lang['resendpwdconfirm']      = 'Odkaz na potvrzovací stránku byl odeslán mailem.';
$lang['resendpwdsuccess']      = 'Vaše nové heslo bylo odesláno emailem.';
$lang['license']               = 'Kromě míst, kde je explicitně uvedeno jinak, je obsah této wiki licencován pod následující licencí:';
$lang['licenseok']             = 'Poznámka: Tím, že editujete tuto stránku, souhlasíte, aby váš obsah byl licencován pod následující licencí:';
$lang['searchmedia']           = 'Hledat jméno souboru:';
$lang['searchmedia_in']        = 'Hledat v %s';
$lang['txt_upload']            = 'Vyberte soubor jako přílohu';
$lang['txt_filename']          = 'Wiki jméno (volitelné)';
$lang['txt_overwrt']           = 'Přepsat existující soubor';
$lang['lockedby']              = 'Právě zamknuto:';
$lang['lockexpire']            = 'Zámek vyprší:';
$lang['js']['willexpire']      = 'Váš zámek pro editaci za chvíli vyprší.\nAbyste předešli konfliktům, stiskněte tlačítko Náhled a zámek se prodlouží.';
$lang['js']['notsavedyet']     = 'Jsou tu neuložené změny, které budou ztraceny.
Chcete opravdu pokračovat?';
$lang['js']['searchmedia']     = 'Hledat soubory';
$lang['js']['keepopen']        = 'Po vybrání souboru nechat okno otevřené';
$lang['js']['hidedetails']     = 'Skrýt detaily';
$lang['js']['mediatitle']      = 'Nastavení odkazu';
$lang['js']['mediadisplay']    = 'Typ odkazu';
$lang['js']['mediaalign']      = 'Zarovnání';
$lang['js']['mediasize']       = 'Velikost obrázku';
$lang['js']['mediatarget']     = 'Cíl odkazu';
$lang['js']['mediaclose']      = 'Zavřít';
$lang['js']['mediainsert']     = 'Vložit';
$lang['js']['mediadisplayimg'] = 'Ukázat obrázek';
$lang['js']['mediadisplaylnk'] = 'Ukázat pouze odkaz';
$lang['js']['mediasmall']      = 'Malá verze';
$lang['js']['mediamedium']     = 'Střední verze';
$lang['js']['medialarge']      = 'Velká verze';
$lang['js']['mediaoriginal']   = 'Původní verze';
$lang['js']['medialnk']        = 'Odkaz na stránku s detailem';
$lang['js']['mediadirect']     = 'Přímý odkaz na originál';
$lang['js']['medianolnk']      = 'Žádný odkaz';
$lang['js']['medianolink']     = 'Neodkazovat na obrázek';
$lang['js']['medialeft']       = 'Zarovnat obrázek doleva.';
$lang['js']['mediaright']      = 'Zarovnat obrázek doprava.';
$lang['js']['mediacenter']     = 'Zarovnat obrázek na střed.';
$lang['js']['medianoalign']    = 'Nepoužívat zarovnání.';
$lang['js']['nosmblinks']      = 'Odkazování na sdílené prostředky Windows funguje jen v Internet Exploreru.
Přesto tento odkaz můžete zkopírovat a vložit jinde.';
$lang['js']['linkwiz']         = 'Průvodce odkazy';
$lang['js']['linkto']          = 'Odkaz na:';
$lang['js']['del_confirm']     = 'Vymazat tuto položku?';
$lang['js']['restore_confirm'] = 'Opravdu obnovit tuto verzi?';
$lang['js']['media_diff']      = 'Prohlédnout rozdíly:';
$lang['js']['media_diff_both'] = 'Vedle sebe';
$lang['js']['media_diff_opacity'] = 'Zvýraznění';
$lang['js']['media_diff_portions'] = 'Osvědčit';
$lang['js']['media_select']    = 'Vybrat soubory...';
$lang['js']['media_upload_btn'] = 'Nahrát';
$lang['js']['media_done_btn']  = 'Hotovo';
$lang['js']['media_drop']      = 'Sem přetáhněte soubory pro nahrátí';
$lang['js']['media_cancel']    = 'odstranit';
$lang['js']['media_overwrt']   = 'Přepsat existující soubory';
$lang['rssfailed']             = 'Nastala chyba při vytváření tohoto RSS: ';
$lang['nothingfound']          = 'Nic nenalezeno.';
$lang['mediaselect']           = 'Výběr dokumentu';
$lang['fileupload']            = 'Načtení dokumentu';
$lang['uploadsucc']            = 'Přenos proběhl v pořádku';
$lang['uploadfail']            = 'Chyba při načítání. Možná kvůli špatně nastaveným právům?';
$lang['uploadwrong']           = 'Načtení souboru s takovouto příponou není dovoleno.';
$lang['uploadexist']           = 'Soubor už existuje, necháme ho být.';
$lang['uploadbadcontent']      = 'Obsah načteného dokumentu %s neodpovídá jeho příponě.';
$lang['uploadspam']            = 'Načtený dokument byl odmítnut, je na spamovém blacklistu.';
$lang['uploadxss']             = 'Načtený dokument byl odmítnut. Zdá se, že obsahuje škodlivé věci.';
$lang['uploadsize']            = 'Nahraný soubor byl příliš velký (max. %s)';
$lang['deletesucc']            = 'Soubor "%s" byl vymazán.';
$lang['deletefail']            = 'Soubor "%s" nelze vymazat - zkontrolujte oprávnění.';
$lang['mediainuse']            = 'Soubor "%s" nebyl vymazán - stále se používá.';
$lang['namespaces']            = 'Jmenné prostory';
$lang['mediafiles']            = 'Dostupné soubory';
$lang['accessdenied']          = 'Nejste autorizován k přístupu na tuto stránku.';
$lang['mediausage']            = 'K odkázání se na tento soubor použijte následující syntax:';
$lang['mediaview']             = 'Zobrazit původní soubor';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Načíst soubor do aktuálního jmenného prostoru. K vytvoření nových jmenných prostorů, přidejte jejich názvy na začátek wiki jména (oddělte dvojtečkou).';
$lang['mediaextchange']        = 'Přípona souboru byla změněna z .%s na .%s!';
$lang['reference']             = 'Odkazy na';
$lang['ref_inuse']             = 'Soubor nelze vymazat, jelikož ho využívají následující stránky:';
$lang['ref_hidden']            = 'Některé odkazy jsou na stránkách, kam nemáte právo přístupu';
$lang['hits']                  = '- počet výskytů';
$lang['quickhits']             = 'Odpovídající stránky';
$lang['toc']                   = 'Obsah';
$lang['current']               = 'aktuální';
$lang['yours']                 = 'Vaše verze';
$lang['diff']                  = 'Zobrazit rozdíly vůči aktuální verzi';
$lang['diff2']                 = 'Zobrazit rozdíly mezi vybranými verzemi';
$lang['difflink']              = 'Odkaz na výstup diff';
$lang['diff_type']             = 'Zobrazit rozdíly:';
$lang['diff_inline']           = 'Vložené';
$lang['diff_side']             = 'Přidané';
$lang['line']                  = 'Řádek';
$lang['breadcrumb']            = 'Historie';
$lang['youarehere']            = 'Umístění';
$lang['lastmod']               = 'Poslední úprava';
$lang['by']                    = 'autor:';
$lang['deleted']               = 'odstraněno';
$lang['created']               = 'vytvořeno';
$lang['restored']              = 'stará verze byla obnovena';
$lang['external_edit']         = 'upraveno mimo DokuWiki';
$lang['summary']               = 'Komentář k úpravám';
$lang['noflash']               = 'Pro přehrání obsahu potřebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
$lang['download']              = 'Stáhnout snippet';
$lang['mail_newpage']          = 'nová stránka:';
$lang['mail_changed']          = 'změna stránky:';
$lang['mail_subscribe_list']   = 'stránky změněné ve jmenném prostoru:';
$lang['mail_new_user']         = 'nový uživatel:';
$lang['mail_upload']           = 'načtený dokument:';
$lang['changes_type']          = 'Prohlednou změny ';
$lang['pages_changes']         = 'stránek';
$lang['media_changes']         = 'souborů médií';
$lang['both_changes']          = 'stránek i médií';
$lang['qb_bold']               = 'Tučně';
$lang['qb_italic']             = 'Kurzíva';
$lang['qb_underl']             = 'Podtržení';
$lang['qb_code']               = 'Neformátovat (zdrojový kód)';
$lang['qb_strike']             = 'Přeškrtnutý text';
$lang['qb_h1']                 = 'Nadpis 1. úrovně';
$lang['qb_h2']                 = 'Nadpis 2. úrovně';
$lang['qb_h3']                 = 'Nadpis 3. úrovně';
$lang['qb_h4']                 = 'Nadpis 4. úrovně';
$lang['qb_h5']                 = 'Nadpis 5. úrovně';
$lang['qb_h']                  = 'Nadpis';
$lang['qb_hs']                 = 'Vybrat nadpis';
$lang['qb_hplus']              = 'Nadpis vyšší úrovně';
$lang['qb_hminus']             = 'Nadpis nižší úrovně';
$lang['qb_hequal']             = 'Nadpis stejné úrovně';
$lang['qb_link']               = 'Interní odkaz';
$lang['qb_extlink']            = 'Externí odkaz';
$lang['qb_hr']                 = 'Vodorovná čára';
$lang['qb_ol']                 = 'Číslovaný seznam';
$lang['qb_ul']                 = 'Nečíslovaný seznam';
$lang['qb_media']              = 'Vložit obrázky nebo jiné soubory';
$lang['qb_sig']                = 'Vložit podpis';
$lang['qb_smileys']            = 'Emotikony';
$lang['qb_chars']              = 'Speciální znaky';
$lang['upperns']               = 'skočit do nadřazeného jmenného prostoru';
$lang['admin_register']        = 'Přidat nového uživatele';
$lang['metaedit']              = 'Upravit Metadata';
$lang['metasaveerr']           = 'Chyba při zápisu metadat';
$lang['metasaveok']            = 'Metadata uložena';
$lang['img_backto']            = 'Zpět na';
$lang['img_title']             = 'Titulek';
$lang['img_caption']           = 'Popis';
$lang['img_date']              = 'Datum';
$lang['img_fname']             = 'Jméno souboru';
$lang['img_fsize']             = 'Velikost';
$lang['img_artist']            = 'Autor fotografie';
$lang['img_copyr']             = 'Copyright';
$lang['img_format']            = 'Formát';
$lang['img_camera']            = 'Typ fotoaparátu';
$lang['img_keywords']          = 'Klíčová slova';
$lang['img_width']             = 'Šířka';
$lang['img_height']            = 'Výška';
$lang['img_manager']           = 'Zobrazit ve správě médií';
$lang['subscr_subscribe_success'] = '%s byl přihlášen do seznamu odběratelů %s';
$lang['subscr_subscribe_error'] = 'Došlo k chybě při přihlašování %s do seznamu odběratelů %s';
$lang['subscr_subscribe_noaddress'] = 'K Vašemu loginu neexistuje žádná adresa, nemohl jste být přihlášen do seznamu odběratelů.';
$lang['subscr_unsubscribe_success'] = '%s byl odhlášen ze seznamu odběratelů %s';
$lang['subscr_unsubscribe_error'] = 'Došlo k chybě při odhlašování %s ze seznamu odběratelů %s';
$lang['subscr_already_subscribed'] = '%s již je přihlášen do seznamu odběratelů %s';
$lang['subscr_not_subscribed'] = '%s není přihlášen do seznamu odběratelů %s';
$lang['subscr_m_not_subscribed'] = 'V současné době neodebíráte změny na aktuální stránce nebo ve jmenném prostoru.';
$lang['subscr_m_new_header']   = 'Přihlásit k odebírání změn emailem';
$lang['subscr_m_current_header'] = 'Aktuální odběratelé změn';
$lang['subscr_m_unsubscribe']  = 'Odhlásit z odběru změn emailem';
$lang['subscr_m_subscribe']    = 'Přihlásit se k odběru změn emailem';
$lang['subscr_m_receive']      = 'Přejete si dostávat';
$lang['subscr_style_every']    = 'email pro každou změnu';
$lang['subscr_style_digest']   = 'souhrnný email změn pro každou stránku (každé %.2f dny/dní)';
$lang['subscr_style_list']     = 'seznam změněných stránek od posledního emailu (každé %.2f dny/dní)';
$lang['authmodfailed']         = 'Autentizace uživatelů je špatně nastavena. Informujte prosím správce této wiki.';
$lang['authtempfail']          = 'Autentizace uživatelů je dočasně nedostupná. Pokud tento problém přetrvává, informujte prosím správce této wiki.';
$lang['i_chooselang']          = 'Vyberte si jazyk';
$lang['i_installer']           = 'Instalace DokuWiki';
$lang['i_wikiname']            = 'Název wiki';
$lang['i_enableacl']           = 'Zapnout ACL (doporučeno)';
$lang['i_superuser']           = 'Správce';
$lang['i_problems']            = 'Instalátor narazil na níže popsané problémy. Nelze pokračovat v instalaci, dokud je neopravíte.';
$lang['i_modified']            = 'Instalátor bude z bezpečnostních důvodů pracovat pouze s čistou a ještě neupravenou instalací DokuWiki. Buď znovu rozbalte soubory z instalačního balíčku, nebo zkuste prostudovat <a href="http://dokuwiki.org/install">instrukce pro instalaci DokuWiki</a>.';
$lang['i_funcna']              = 'PHP funkce <code>%s</code> není dostupná. Váš webhosting ji možná z nějakého důvodu vypnul.';
$lang['i_phpver']              = 'Verze vaší instalace PHP <code>%s</code> je nižší než požadovaná <code>%s</code>. Budete muset aktualizovat svou instalaci PHP.';
$lang['i_permfail']            = 'DokuWiki nemůže zapisovat do <code>%s</code>. Budete muset opravit práva k tomuto adresáři.';
$lang['i_confexists']          = '<code>%s</code> již existuje';
$lang['i_writeerr']            = 'Nelze vytvořit <code>%s</code>. Budete muset zkontrolovat práva k souborům či adresářům a vytvořit tento soubor ručně.';
$lang['i_badhash']             = 'soubor dokuwiki.php (hash=<code>%s</code>) nebyl rozpoznán nebo byl upraven';
$lang['i_badval']              = '<code>%s</code> - neplatná nebo prázdná hodnota';
$lang['i_success']             = 'Konfigurace byla úspěšně dokončena. Nyní můžete smazat soubor install.php. Pokračujte do <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_failure']             = 'Vyskytly se nějaké chyby při zápisu do konfiguračních souborů. Budete je nejspíš muset upravit ručně před použitím <a href="doku.php">své nové DokuWiki</a>.';
$lang['i_policy']              = 'Úvodní politika ACL';
$lang['i_pol0']                = 'Otevřená wiki (čtení, zápis a upload pro všechny)';
$lang['i_pol1']                = 'Veřejná wiki (čtení pro všechny, zápis a upload pro registrované uživatele)';
$lang['i_pol2']                = 'Uzavřená wiki (čtení, zápis a upload pouze pro registrované uživatele)';
$lang['i_retry']               = 'Zkusit znovu';
$lang['i_license']             = 'Vyberte prosím licenci obsahu:';
$lang['recent_global']         = 'Právě si prohlížíte změny ve jmenném prostoru <b>%s</b>. Také si můžete <a href="%s">zobrazit změny v celé wiki</a>.';
$lang['years']                 = 'před %d roky';
$lang['months']                = 'před %d měsíci';
$lang['weeks']                 = 'před %d týdny';
$lang['days']                  = 'před %d dny';
$lang['hours']                 = 'před %d hodinami';
$lang['minutes']               = 'před %d minutami';
$lang['seconds']               = 'před %d sekundami';
$lang['wordblock']             = 'Vaše změny nebyly uloženy, protože obsahují blokovaný text(spam).';
$lang['media_uploadtab']       = 'Nahrát';
$lang['media_searchtab']       = 'Hledat';
$lang['media_file']            = 'Soubor';
$lang['media_viewtab']         = 'Zobrazit';
$lang['media_edittab']         = 'Upravit';
$lang['media_historytab']      = 'Historie';
$lang['media_list_thumbs']     = 'Zmenšeniny';
$lang['media_list_rows']       = 'Řádky';
$lang['media_sort_name']       = 'Jméno';
$lang['media_sort_date']       = 'Datum';
$lang['media_namespaces']      = 'Vyber jmenný prostor';
$lang['media_files']           = 'Soubory v %s';
$lang['media_upload']          = 'Upload do %s';
$lang['media_search']          = 'Hledat v %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s na %s';
$lang['media_edit']            = 'Upravit %s';
$lang['media_history']         = 'Historie %s';
$lang['media_meta_edited']     = 'metadata upravena';
$lang['media_perm_read']       = 'Bohužel, nemáte práva číst soubory.';
$lang['media_perm_upload']     = 'Bohužel, nemáte práva nahrávat soubory.';
$lang['media_update']          = 'Nahrát novou verzi';
$lang['media_restore']         = 'Obnovit tuto verzi';
$lang['plugin_install_err']    = 'Plugin je špatně nainstalován. Přejmenujte adresář pluginu \'%s\' na \'%s\'.';
